diff --git a/alinco/alinco.h b/alinco/alinco.h
index eddbe2420..97c3acf30 100644
--- a/alinco/alinco.h
+++ b/alinco/alinco.h
@@ -1,8 +1,8 @@
 /*
  *  Hamlib Alinco backend - main header
- *  Copyright (c) 2001 by Stephane Fillod
+ *  Copyright (c) 2001,2002 by Stephane Fillod
  *
- *		$Id: alinco.h,v 1.9 2001-12-19 03:35:27 fillods Exp $
+ *		$Id: alinco.h,v 1.10 2001-12-28 20:28:02 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -56,7 +56,7 @@ int alinco_get_mem(RIG *rig, vfo_t vfo, int *ch);
 
 extern const struct rig_caps dx77_caps;
 
-extern BACKEND_EXPORT(int) init_alinco(void *be_handle);
+extern BACKEND_EXPORT(int) initrigs_alinco(void *be_handle);
 
 
 #endif /* _ALINCO_H */
diff --git a/aor/aor.h b/aor/aor.h
index 64d361689..a043b12c9 100644
--- a/aor/aor.h
+++ b/aor/aor.h
@@ -1,8 +1,8 @@
 /*
  *  Hamlib AOR backend - main header
- *  Copyright (c) 2000,2001 by Stephane Fillod
+ *  Copyright (c) 2000,2001,2002 by Stephane Fillod
  *
- *		$Id: aor.h,v 1.8 2001-12-16 11:14:46 fillods Exp $
+ *		$Id: aor.h,v 1.9 2001-12-28 20:28:03 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -37,7 +37,7 @@ int aor_set_powerstat(RIG *rig, powerstat_t status);
 extern const struct rig_caps ar8200_caps;
 extern const struct rig_caps ar8000_caps;
 
-extern BACKEND_EXPORT(int) init_aor(void *be_handle);
+extern BACKEND_EXPORT(int) initrigs_aor(void *be_handle);
 
 
 #endif /* _AOR_H */
diff --git a/dummy/dummy.c b/dummy/dummy.c
index 0c8fead05..9e44ef5d6 100644
--- a/dummy/dummy.c
+++ b/dummy/dummy.c
@@ -1,8 +1,8 @@
 /*
  *  Hamlib Dummy backend - main file
- *  Copyright (c) 2001 by Stephane Fillod
+ *  Copyright (c) 2001,2002 by Stephane Fillod
  *
- *		$Id: dummy.c,v 1.20 2001-12-26 23:37:46 fillods Exp $
+ *		$Id: dummy.c,v 1.21 2001-12-28 20:28:03 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -665,7 +665,7 @@ const struct rig_caps dummy_caps = {
   get_trn:	dummy_get_trn,
 };
 
-int init_dummy(void *be_handle)
+int initrigs_dummy(void *be_handle)
 {
 	rig_debug(RIG_DEBUG_VERBOSE, "dummy: _init called\n");
 
diff --git a/dummy/dummy.h b/dummy/dummy.h
index 08031116f..ee10f7283 100644
--- a/dummy/dummy.h
+++ b/dummy/dummy.h
@@ -1,8 +1,8 @@
 /*
  *  Hamlib Dummy backend - main header
- *  Copyright (c) 2001 by Stephane Fillod
+ *  Copyright (c) 2001,2002 by Stephane Fillod
  *
- *		$Id: dummy.h,v 1.4 2001-12-16 11:14:46 fillods Exp $
+ *		$Id: dummy.h,v 1.5 2001-12-28 20:28:03 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -26,6 +26,6 @@
 
 extern const struct rig_caps dummy_caps;
 
-extern BACKEND_EXPORT(int) init_dummy(void *be_handle);
+extern BACKEND_EXPORT(int) initrigs_dummy(void *be_handle);
 
 #endif /* _DUMMY_H */
diff --git a/icom/icom.h b/icom/icom.h
index 58dc85022..24d8b7442 100644
--- a/icom/icom.h
+++ b/icom/icom.h
@@ -1,8 +1,8 @@
 /*
  *  Hamlib CI-V backend - main header
- *  Copyright (c) 2000,2001 by Stephane Fillod
+ *  Copyright (c) 2000,2001,2002 by Stephane Fillod
  *
- *		$Id: icom.h,v 1.35 2001-12-20 23:07:14 fillods Exp $
+ *		$Id: icom.h,v 1.36 2001-12-28 20:28:03 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -119,8 +119,8 @@ extern const struct rig_caps icall_caps;
 extern const struct rig_caps ic275_caps;
 extern const struct rig_caps ic475_caps;
 
-extern BACKEND_EXPORT(rig_model_t) probe_icom(port_t *p);
-extern BACKEND_EXPORT(int) init_icom(void *be_handle);
+extern BACKEND_EXPORT(rig_model_t) proberigs_icom(port_t *p);
+extern BACKEND_EXPORT(int) initrigs_icom(void *be_handle);
 
 
 #endif /* _ICOM_H */
diff --git a/jrc/jrc.h b/jrc/jrc.h
index 4fabf265a..6b612a58d 100644
--- a/jrc/jrc.h
+++ b/jrc/jrc.h
@@ -1,8 +1,8 @@
 /*
  *  Hamlib JRC backend - main header
- *  Copyright (c) 2001 by Stephane Fillod
+ *  Copyright (c) 2001,2002 by Stephane Fillod
  *
- *		$Id: jrc.h,v 1.3 2001-12-20 23:03:26 fillods Exp $
+ *		$Id: jrc.h,v 1.4 2001-12-28 20:28:03 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -52,7 +52,7 @@ int jrc_decode_event(RIG *rig);
 
 extern const struct rig_caps nrd545_caps;
 
-extern BACKEND_EXPORT(int) init_jrc(void *be_handle);
+extern BACKEND_EXPORT(int) initrigs_jrc(void *be_handle);
 
 
 #endif /* _JRC_H */
diff --git a/kachina/kachina.h b/kachina/kachina.h
index 7ecd1a616..2c42714ec 100644
--- a/kachina/kachina.h
+++ b/kachina/kachina.h
@@ -1,8 +1,8 @@
 /*
  *  Hamlib Kachina backend - main header
- *  Copyright (c) 2001 by Stephane Fillod
+ *  Copyright (c) 2001,2002 by Stephane Fillod
  *
- *		$Id: kachina.h,v 1.2 2001-12-20 08:02:44 fillods Exp $
+ *		$Id: kachina.h,v 1.3 2001-12-28 20:28:03 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -36,7 +36,7 @@ int kachina_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width);
 
 extern const struct rig_caps k505dsp_caps;
 
-extern BACKEND_EXPORT(int) init_kachina(void *be_handle);
+extern BACKEND_EXPORT(int) initrigs_kachina(void *be_handle);
 
 
 #endif /* _KACHINA_H */
diff --git a/kenwood/kenwood.h b/kenwood/kenwood.h
index f9e1cb797..b2433d3f2 100644
--- a/kenwood/kenwood.h
+++ b/kenwood/kenwood.h
@@ -1,8 +1,8 @@
 /*
  *  Hamlib Kenwood backend - main header
- *  Copyright (c) 2000,2001 by Stephane Fillod
+ *  Copyright (c) 2000,2001,2002 by Stephane Fillod
  *
- *		$Id: kenwood.h,v 1.14 2001-12-20 07:46:12 fillods Exp $
+ *		$Id: kenwood.h,v 1.15 2001-12-28 20:28:03 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -62,8 +62,8 @@ extern const struct rig_caps thd7a_caps;
 extern const struct rig_caps thf7a_caps;
 extern const struct rig_caps thf7e_caps;
 
-extern BACKEND_EXPORT(int) init_kenwood(void *be_handle);
-extern BACKEND_EXPORT(rig_model_t) probe_kenwood(port_t *port);
+extern BACKEND_EXPORT(int) initrigs_kenwood(void *be_handle);
+extern BACKEND_EXPORT(rig_model_t) proberigs_kenwood(port_t *port);
 
 
 #endif /* _KENWOOD_H */
diff --git a/pcr/pcr.h b/pcr/pcr.h
index 1c6d67c1c..3ce13dc8d 100644
--- a/pcr/pcr.h
+++ b/pcr/pcr.h
@@ -1,8 +1,8 @@
 /*
  *  Hamlib PCR backend - main header
- *  Copyright (c) 2001 by Stephane Fillod
+ *  Copyright (c) 2001,2002 by Stephane Fillod
  *
- *		$Id: pcr.h,v 1.5 2001-12-16 11:14:46 fillods Exp $
+ *		$Id: pcr.h,v 1.6 2001-12-28 20:28:03 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -44,7 +44,7 @@ const char *pcr_get_info(RIG *rig);
 extern const struct rig_caps pcr1000_caps;
 extern const struct rig_caps pcr100_caps;
 
-extern BACKEND_EXPORT(int) init_pcr(void *be_handle);
+extern BACKEND_EXPORT(int) initrigs_pcr(void *be_handle);
 
 
 #endif /* _PCR_H */
diff --git a/rpcrig/rpcrig_backend.c b/rpcrig/rpcrig_backend.c
index 7b12e4f3b..2868f4339 100644
--- a/rpcrig/rpcrig_backend.c
+++ b/rpcrig/rpcrig_backend.c
@@ -1,8 +1,8 @@
 /*
  *  Hamlib RPC backend - main file
- *  Copyright (c) 2001 by Stephane Fillod
+ *  Copyright (c) 2001,2002 by Stephane Fillod
  *
- *		$Id: rpcrig_backend.c,v 1.5 2001-12-27 21:56:01 fillods Exp $
+ *		$Id: rpcrig_backend.c,v 1.6 2001-12-28 20:28:03 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -1022,7 +1022,7 @@ struct rig_caps rpcrig_caps = {
   get_trn:	rpcrig_get_trn,
 };
 
-int init_rpcrig(void *be_handle)
+int initrigs_rpcrig(void *be_handle)
 {
 	rig_debug(RIG_DEBUG_VERBOSE, "rpcrig: _init called\n");
 
diff --git a/rpcrig/rpcrig_backend.h b/rpcrig/rpcrig_backend.h
index 6ce51e354..f7e444ae4 100644
--- a/rpcrig/rpcrig_backend.h
+++ b/rpcrig/rpcrig_backend.h
@@ -1,8 +1,8 @@
 /*
  *  Hamlib RPC backend - main header
- *  Copyright (c) 2001 by Stephane Fillod
+ *  Copyright (c) 2001,2002 by Stephane Fillod
  *
- *		$Id: rpcrig_backend.h,v 1.3 2001-12-26 23:43:05 fillods Exp $
+ *		$Id: rpcrig_backend.h,v 1.4 2001-12-28 20:28:03 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -26,6 +26,6 @@
 
 extern struct rig_caps rpcrig_caps;
 
-extern BACKEND_EXPORT(int) init_rpcrig(void *be_handle);
+extern BACKEND_EXPORT(int) initrigs_rpcrig(void *be_handle);
 
 #endif /* _RPCRIG_H */
diff --git a/src/register.c b/src/register.c
index 4308052dc..299033dfd 100644
--- a/src/register.c
+++ b/src/register.c
@@ -2,7 +2,7 @@
  *  Hamlib Interface - provides registering for dynamically loadable backends.
  *  Copyright (c) 2000,2001 by Stephane Fillod and Frank Singleton
  *
- *		$Id: register.c,v 1.13 2001-12-19 03:54:41 fillods Exp $
+ *		$Id: register.c,v 1.14 2001-12-28 20:28:02 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -274,8 +274,8 @@ int rig_load_backend(const char *be_name)
     int (*be_init)(rig_ptr_t);
 	int status;
 	char libname[PATH_MAX];
-	char initfname[MAXFUNCNAMELEN]  = "init_";
-	char probefname[MAXFUNCNAMELEN] = "probe_";
+	char initfname[MAXFUNCNAMELEN]  = "initrigs_";
+	char probefname[MAXFUNCNAMELEN] = "proberigs_";
 	int i;
 
 	/*
diff --git a/tentec/tentec.h b/tentec/tentec.h
index 236b06fec..7613f04b8 100644
--- a/tentec/tentec.h
+++ b/tentec/tentec.h
@@ -1,8 +1,8 @@
 /*
  *  Hamlib Tentec backend - main header
- *  Copyright (c) 2001 by Stephane Fillod
+ *  Copyright (c) 2001,2002 by Stephane Fillod
  *
- *		$Id: tentec.h,v 1.2 2001-12-16 11:14:46 fillods Exp $
+ *		$Id: tentec.h,v 1.3 2001-12-28 20:28:04 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -60,7 +60,7 @@ const char* tentec_get_info(RIG *rig);
 
 extern const struct rig_caps rx320_caps;
 
-extern BACKEND_EXPORT(int) init_tentec(void *be_handle);
+extern BACKEND_EXPORT(int) initrigs_tentec(void *be_handle);
 
 
 #endif /* _TENTEC_H */
diff --git a/uniden/uniden.h b/uniden/uniden.h
index a57443e69..d5eaa4606 100644
--- a/uniden/uniden.h
+++ b/uniden/uniden.h
@@ -1,8 +1,8 @@
 /*
  *  Hamlib Uniden backend - main header
- *  Copyright (c) 2001 by Stephane Fillod
+ *  Copyright (c) 2001,2002 by Stephane Fillod
  *
- *		$Id: uniden.h,v 1.2 2001-12-16 11:14:46 fillods Exp $
+ *		$Id: uniden.h,v 1.3 2001-12-28 20:28:04 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -32,7 +32,7 @@ int uniden_set_mem(RIG *rig, vfo_t vfo, int ch);
 
 extern const struct rig_caps bc895_caps;
 
-extern BACKEND_EXPORT(int) init_uniden(void *be_handle);
+extern BACKEND_EXPORT(int) initrigs_uniden(void *be_handle);
 
 
 #endif /* _UNIDEN_H */
diff --git a/winradio/winradio.c b/winradio/winradio.c
index e637cbdbf..652f87286 100644
--- a/winradio/winradio.c
+++ b/winradio/winradio.c
@@ -3,7 +3,7 @@
  *  Copyright (C) 2001 pab@users.sourceforge.net
  *  Derived from hamlib code (C) 2000,2001 Stephane Fillod.
  *
- *		$Id: winradio.c,v 1.15 2001-12-16 11:14:46 fillods Exp $
+ *		$Id: winradio.c,v 1.16 2001-12-28 20:28:04 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -231,7 +231,7 @@ const char *wr_get_info(RIG *rig) {
 }
 
 
-int init_winradio(void *be_handle)
+int initrigs_winradio(void *be_handle)
 {
 	rig_debug(RIG_DEBUG_VERBOSE, "winradio: _init called\n");
 
diff --git a/winradio/winradio.h b/winradio/winradio.h
index c5d0ab7aa..104f7f83c 100644
--- a/winradio/winradio.h
+++ b/winradio/winradio.h
@@ -1,8 +1,8 @@
 /*
  *  Hamlib WiNRADiO backend - main header
- *  Copyright (c) 2000,2001 by Stephane Fillod
+ *  Copyright (c) 2000,2001,2002 by Stephane Fillod
  *
- *		$Id: winradio.h,v 1.6 2001-12-16 11:14:47 fillods Exp $
+ *		$Id: winradio.h,v 1.7 2001-12-28 20:28:04 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -46,6 +46,6 @@ extern const struct rig_caps wr3150_caps;
 extern const struct rig_caps wr3500_caps;
 extern const struct rig_caps wr3700_caps;
 
-extern BACKEND_EXPORT(int) init_winradio(void *be_handle);
+extern BACKEND_EXPORT(int) initrigs_winradio(void *be_handle);
 
 #endif /* _WINRADIO_H */
diff --git a/yaesu/yaesu.h b/yaesu/yaesu.h
index 9527c656a..fd2e036f6 100644
--- a/yaesu/yaesu.h
+++ b/yaesu/yaesu.h
@@ -2,9 +2,11 @@
  * hamlib - (C) Frank Singleton 2000 (vk3fcs@ix.netcom.com)
  *
  * yaesu.h - (C) Frank Singleton 2000 (vk3fcs@ix.netcom.com)
+ * 					and Stephane Fillod 2001,2002
+ *
  * Common yaesu declarations for hamlib
  *
- * 	$Id: yaesu.h,v 1.8 2001-12-16 11:14:47 fillods Exp $	
+ * 	$Id: yaesu.h,v 1.9 2001-12-28 20:28:04 fillods Exp $	
  *
  *
  *
@@ -49,6 +51,6 @@ extern const struct rig_caps ft747_caps;
 extern const struct rig_caps ft817_caps;
 extern const struct rig_caps ft847_caps;
 
-extern BACKEND_EXPORT(int) init_yaesu(void *be_handle);
+extern BACKEND_EXPORT(int) initrigs_yaesu(void *be_handle);
 
 #endif /* _YAESU_H */
diff --git a/alinco/alinco.c b/alinco/alinco.c
index 56b705906..14e0d6b0e 100644
--- a/alinco/alinco.c
+++ b/alinco/alinco.c
@@ -1,8 +1,8 @@
 /*
  *  Hamlib Alinco backend - main file
- *  Copyright (c) 2001 by Stephane Fillod
+ *  Copyright (c) 2001,2002 by Stephane Fillod
  *
- *		$Id: alinco.c,v 1.11 2001-12-20 22:59:07 fillods Exp $
+ *		$Id: alinco.c,v 1.12 2001-12-28 20:28:02 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -830,9 +830,9 @@ int alinco_get_mem(RIG *rig, vfo_t vfo, int *ch)
 
 
 /*
  * init_alinco is called by rig_backend_load
  */
-int init_alinco(void *be_handle)
+int initrigs_alinco(void *be_handle)
 {
 		rig_debug(RIG_DEBUG_VERBOSE, "alinco: _init called\n");
 
@@ -830,9 +830,9 @@ int alinco_get_mem(RIG *rig, vfo_t vfo, int *ch)
 
 /*
- * init_alinco is called by rig_backend_load
+ * initrigs_alinco is called by rig_backend_load
  */
diff --git a/aor/aor.c b/aor/aor.c
index 8fa4e55d1..72ebba93b 100644
--- a/aor/aor.c
+++ b/aor/aor.c
@@ -1,8 +1,8 @@
 /*
  *  Hamlib AOR backend - main file
- *  Copyright (c) 2000,2001 by Stephane Fillod
+ *  Copyright (c) 2000,2001,2002 by Stephane Fillod
  *
- *		$Id: aor.c,v 1.16 2001-12-20 22:59:08 fillods Exp $
+ *		$Id: aor.c,v 1.17 2001-12-28 20:28:03 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -299,9 +299,9 @@ int aor_set_powerstat(RIG *rig, powerstat_t status)
 
 
 /*
  * init_aor is called by rig_backend_load
  */
-int init_aor(void *be_handle)
+int initrigs_aor(void *be_handle)
 {
 		rig_debug(RIG_DEBUG_VERBOSE, "aor: _init called\n");
 
@@ -299,9 +299,9 @@ int aor_set_powerstat(RIG *rig, powerstat_t status)
 
 /*
- * init_aor is called by rig_backend_load
+ * initrigs_aor is called by rig_backend_load
  */
diff --git a/icom/icom.c b/icom/icom.c
index c51453b6d..1e78168a2 100644
--- a/icom/icom.c
+++ b/icom/icom.c
@@ -1,8 +1,8 @@
 /*
  *  Hamlib CI-V backend - main file
- *  Copyright (c) 2000,2001 by Stephane Fillod
+ *  Copyright (c) 2000,2001,2002 by Stephane Fillod
  *
- *		$Id: icom.c,v 1.46 2001-12-20 23:07:13 fillods Exp $
+ *		$Id: icom.c,v 1.47 2001-12-28 20:28:03 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -2279,9 +2279,9 @@ rig_model_t probe_icom(port_t *p)
 }
 
 /*
  * init_icom is called by rig_backend_load
  */
-int init_icom(void *be_handle)
+int initrigs_icom(void *be_handle)
 {
 		rig_debug(RIG_DEBUG_VERBOSE, "icom: _init called\n");
 
@@ -2279,9 +2279,9 @@ rig_model_t probe_icom(port_t *p)
 
 /*
- * init_icom is called by rig_backend_load
+ * initrigs_icom is called by rig_backend_load
  */
diff --git a/jrc/jrc.c b/jrc/jrc.c
index f5ce380ce..c928e24fd 100644
--- a/jrc/jrc.c
+++ b/jrc/jrc.c
@@ -1,8 +1,8 @@
 /*
  *  Hamlib JRC backend - main file
- *  Copyright (c) 2001 by Stephane Fillod
+ *  Copyright (c) 2001,2002 by Stephane Fillod
  *
- *		$Id: jrc.c,v 1.3 2001-12-20 23:03:26 fillods Exp $
+ *		$Id: jrc.c,v 1.4 2001-12-28 20:28:03 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -869,9 +869,9 @@ int jrc_decode_event(RIG *rig)
 
 
 /*
  * init_jrc is called by rig_backend_load
  */
-int init_jrc(void *be_handle)
+int initrigs_jrc(void *be_handle)
 {
 		rig_debug(RIG_DEBUG_VERBOSE, "jrc: _init called\n");
 
@@ -869,9 +869,9 @@ int jrc_decode_event(RIG *rig)
 
 /*
- * init_jrc is called by rig_backend_load
+ * initrigs_jrc is called by rig_backend_load
  */
diff --git a/kachina/kachina.c b/kachina/kachina.c
index 86ca10874..b6c45362c 100644
--- a/kachina/kachina.c
+++ b/kachina/kachina.c
@@ -1,8 +1,8 @@
 /*
  *  Hamlib Kachina backend - main file
- *  Copyright (c) 2001 by Stephane Fillod
+ *  Copyright (c) 2001,2002 by Stephane Fillod
  *
- *		$Id: kachina.c,v 1.2 2001-12-20 08:02:44 fillods Exp $
+ *		$Id: kachina.c,v 1.3 2001-12-28 20:28:03 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -204,9 +204,9 @@ int kachina_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 }
 
 /*
  * init_kachina is called by rig_backend_load
  */
-int init_kachina(void *be_handle)
+int initrigs_kachina(void *be_handle)
 {
 		rig_debug(RIG_DEBUG_VERBOSE, "kachina: _init called\n");
 
@@ -204,9 +204,9 @@ int kachina_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 
 /*
- * init_kachina is called by rig_backend_load
+ * initrigs_kachina is called by rig_backend_load
  */
diff --git a/kenwood/kenwood.c b/kenwood/kenwood.c
index f8f38ccca..58221d776 100644
--- a/kenwood/kenwood.c
+++ b/kenwood/kenwood.c
@@ -1,8 +1,8 @@
 /*
  *  Hamlib Kenwood backend - main file
- *  Copyright (c) 2000,2001 by Stephane Fillod
+ *  Copyright (c) 2000,2001,2002 by Stephane Fillod
  *
- *		$Id: kenwood.c,v 1.22 2001-12-20 22:59:08 fillods Exp $
+ *		$Id: kenwood.c,v 1.23 2001-12-28 20:28:03 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -1035,9 +1035,9 @@ rig_model_t probe_kenwood(port_t *port)
 
 
 /*
  * init_kenwood is called by rig_backend_load
  */
-int init_kenwood(void *be_handle)
+int initrigs_kenwood(void *be_handle)
 {
 		rig_debug(RIG_DEBUG_VERBOSE, "kenwood: _init called\n");
 
@@ -1035,9 +1035,9 @@ rig_model_t probe_kenwood(port_t *port)
 
 /*
- * init_kenwood is called by rig_backend_load
+ * initrigs_kenwood is called by rig_backend_load
  */
diff --git a/pcr/pcr.c b/pcr/pcr.c
index 73b8969c7..766ffdf4d 100644
--- a/pcr/pcr.c
+++ b/pcr/pcr.c
@@ -1,8 +1,8 @@
 /*
  *  Hamlib PCR backend - main file
- *  Copyright (c) 2001 by Stephane Fillod
+ *  Copyright (c) 2001,2002 by Stephane Fillod
  *
- *		$Id: pcr.c,v 1.10 2001-12-16 11:14:46 fillods Exp $
+ *		$Id: pcr.c,v 1.11 2001-12-28 20:28:03 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -409,9 +409,9 @@ const char *pcr_get_info(RIG *rig)
 
 
 /*
  * init_pcr is called by rig_backend_load
  */
-int init_pcr(void *be_handle)
+int initrigs_pcr(void *be_handle)
 {
 		rig_debug(RIG_DEBUG_VERBOSE, "pcr: _init called\n");
 
@@ -409,9 +409,9 @@ const char *pcr_get_info(RIG *rig)
 
 /*
- * init_pcr is called by rig_backend_load
+ * initrigs_pcr is called by rig_backend_load
  */
diff --git a/tentec/tentec.c b/tentec/tentec.c
index 8153578c0..422b84ca9 100644
--- a/tentec/tentec.c
+++ b/tentec/tentec.c
@@ -1,8 +1,8 @@
 /*
  *  Hamlib Tentec backend - main file
- *  Copyright (c) 2001 by Stephane Fillod
+ *  Copyright (c) 2001,2002 by Stephane Fillod
  *
- *		$Id: tentec.c,v 1.2 2001-12-16 11:14:46 fillods Exp $
+ *		$Id: tentec.c,v 1.3 2001-12-28 20:28:03 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -431,9 +431,9 @@ const char *tentec_get_info(RIG *rig)
 
 
 /*
  * init_tentec is called by rig_backend_load
  */
-int init_tentec(void *be_handle)
+int initrigs_tentec(void *be_handle)
 {
 		rig_debug(RIG_DEBUG_VERBOSE, "tentec: _init called\n");
 
@@ -431,9 +431,9 @@ const char *tentec_get_info(RIG *rig)
 
 /*
- * init_tentec is called by rig_backend_load
+ * initrigs_tentec is called by rig_backend_load
  */
diff --git a/uniden/uniden.c b/uniden/uniden.c
index 59d230548..80aca489a 100644
--- a/uniden/uniden.c
+++ b/uniden/uniden.c
@@ -1,8 +1,8 @@
 /*
  *  Hamlib Uniden backend - main file
- *  Copyright (c) 2001 by Stephane Fillod
+ *  Copyright (c) 2001,2002 by Stephane Fillod
  *
- *		$Id: uniden.c,v 1.2 2001-12-16 11:14:46 fillods Exp $
+ *		$Id: uniden.c,v 1.3 2001-12-28 20:28:04 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -127,9 +127,9 @@ int uniden_set_mem(RIG *rig, vfo_t vfo, int ch)
 }
 
 /*
  * init_uniden is called by rig_backend_load
  */
-int init_uniden(void *be_handle)
+int initrigs_uniden(void *be_handle)
 {
 		rig_debug(RIG_DEBUG_VERBOSE, "uniden: _init called\n");
 
@@ -127,9 +127,9 @@ int uniden_set_mem(RIG *rig, vfo_t vfo, int ch)
 
 /*
- * init_uniden is called by rig_backend_load
+ * initrigs_uniden is called by rig_backend_load
  */
diff --git a/yaesu/yaesu.c b/yaesu/yaesu.c
index dd01178b6..2b7d36ad4 100644
--- a/yaesu/yaesu.c
+++ b/yaesu/yaesu.c
@@ -1,13 +1,13 @@
 /*
  * hamlib - (C) Frank Singleton 2000 (vk3fcs@ix.netcom.com)
  *
- * yaesu.c - (C) Stephane Fillod 2001
+ * yaesu.c - (C) Stephane Fillod 2001,2002
  *
  * This shared library provides an API for communicating
  * via serial interface to a Yaesu rig
  *
  *
- *	$Id: yaesu.c,v 1.5 2001-12-16 11:14:47 fillods Exp $  
+ *	$Id: yaesu.c,v 1.6 2001-12-28 20:28:04 fillods Exp $  
  *
  *
  * This program is free software; you can redistribute it and/or
@@ -45,10 +45,10 @@
 
 
 /*
  * init_yaesu is called by rig_backend_load
  */
 
-int init_yaesu(void *be_handle)
+int initrigs_yaesu(void *be_handle)
 {
   rig_debug(RIG_DEBUG_VERBOSE, "yaesu: _init called\n");
 
@@ -45,10 +45,10 @@
 
 /*
- * init_yaesu is called by rig_backend_load
+ * initrigs_yaesu is called by rig_backend_load
  */
 